import { CloseOutlined } from "@ant-design/icons";
import Color from "color";
import { PropsWithChildren } from "react";
import styles from "./index.module.css";

interface ModalProps {
  visible: boolean;
  width?: number;
  height?: number;
  contentStyle?: React.CSSProperties;
  onClose: () => void;
  zIndex?: number;
}

const BasicModal: React.FC<PropsWithChildren<ModalProps>> = (props) => {
  const {
    visible = true,
    children,
    contentStyle,
    onClose,
    width,
    height,
    zIndex,
  } = props;

  if (!visible) {
    return null;
  }

  return (
    <div
      className={styles.modalWrap}
      style={{ zIndex }}
      // 禁止弹窗冒泡
      onClick={(e) => e.stopPropagation()}
    >
      <div className={styles.modalMask} />
      <div className={styles.modalContentWrap}>
        <div
          className={styles.modalContent}
          style={{ width, height, ...contentStyle }}
        >
          <div className={styles.closeBtn} onClick={onClose}>
            <CloseOutlined
              style={{ color: Color("#596576").alpha(0.5).hexa() }}
            />
          </div>
          {children}
        </div>
      </div>
    </div>
  );
};

export default BasicModal;
