import Checkbox from "@/customForm/components/Checkbox";
import DatePicker from "@/customForm/components/DatePicker";
import FileUpload from "@/customForm/components/FileUpload";
import List from "@/customForm/components/List";
import FormRadio from "@/customForm/components/Radio";
import HnSelect from "@/customForm/components/Select";
import UserSelect from "@/customForm/components/UserSelect";
import ImageUpload from "@/customForm/components/ImageUpload";
import { ComponentsType } from "@/customForm/interfaces";
import { Input } from "antd";
import { useMemo } from "react";
import Group from "@/customForm/components/Group";
import BaseFormComponent from "@/customForm/entity/base";

interface RenderComponentProps {
  config?: any;
  onChange?: (value: any) => void;
  value?: any;
  componentType: ComponentsType;
  /** 原始信息 */
  metaData?: BaseFormComponent;
}

const RenderComponent = (props: RenderComponentProps) => {
  const { config, componentType, metaData, ...newProps } = props;

  const componentsRegister = useMemo(() => {
    const composeProps = { ...newProps, ...config, metaData: metaData };

    switch (componentType) {
      case "TextInput":
        return <Input {...composeProps} />;
      case "NumberInput":
        return <Input {...composeProps} />;
      case "Branch":
        return <Group {...composeProps}></Group>;
      case "DatePicker":
        return <DatePicker {...composeProps}></DatePicker>;
      case "TextAreaInput":
        return <Input.TextArea {...composeProps} />;
      case "Radio":
        return <FormRadio {...composeProps} />;
      case "Select":
        return <HnSelect {...composeProps}></HnSelect>;
      case "FileUpload":
        return <FileUpload {...composeProps}></FileUpload>;
      case "ImgUpload":
        return <ImageUpload {...composeProps}></ImageUpload>;
      case "Checkbox":
        return <Checkbox {...composeProps}></Checkbox>;
      case "List":
        return <List {...composeProps}></List>;
      case "UserSelect":
        return <UserSelect {...composeProps}></UserSelect>;
      case "PhoneInput":
        return <Input {...composeProps} />;
      default:
        return "";
    }
  }, [props]);

  return componentsRegister;
};

export default RenderComponent;
