import { CheckOutlined } from "@ant-design/icons";
import styles from "./index.module.css";
import { useEffect, useState } from "react";
import { isEqual } from "lodash";
import { Flex } from "antd";

interface CheckboxProps {
  value: boolean | string;
  onChange?: (value: boolean | string[]) => void;
  options?:
    | {
        label: string;
        value: string;
      }[]
    | string[];
}

const Checkbox = ({ value, onChange, options }: CheckboxProps) => {
  const [selected, setSelected] = useState<string[]>([]);

  useEffect(() => {
    if (typeof value === "string" && value.length != 0) {
      const newV = value.split(",");
      if (!isEqual(newV, selected)) {
        setSelected(newV);
      }
    }
  }, [value]);

  if (!options || options.length === 0) {
    return (
      <div
        onClick={onChange?.bind(this, !value)}
        className={value ? styles.checked : styles.unchecked}
      >
        <CheckOutlined style={{ color: "#fff" }} />
      </div>
    );
  }

  let optionTemp: any[] = [...options];
  optionTemp = optionTemp.map((v: any) => {
    if (typeof v === "string") return { label: v, value: v };

    return v;
  });

  const onclick = (params: string) => {
    if (selected.includes(params)) {
      const newP = selected.filter((item) => item !== params);
      setSelected(newP);
      onChange && onChange(newP.join(",") as any);
    } else {
      setSelected([...selected, params]);
      onChange && onChange([...selected, params].join(",") as any);
    }
  };

  return (
    <div>
      {optionTemp.map((v, i) => {
        return (
          <Flex
            gap={12}
            align="center"
            style={{ marginTop: i !== 0 ? 12 : 0, boxSizing: "border-box" }}
            key={v.value}
          >
            <div
              onClick={onclick?.bind(this, v.value)}
              className={
                selected.includes(v.value) ? styles.checked : styles.unchecked
              }
            >
              <CheckOutlined style={{ color: "#fff" }} />
            </div>
            <div>{v.label}</div>
          </Flex>
        );
      })}
    </div>
  );
};

export default Checkbox;
