import { Space } from "antd";
import React, { PropsWithChildren, useMemo } from "react";
import DecoratePoint from "./components/decoratePoint";
import styles from "./content.module.css";
import LabelText from "./components/labelText";
import BaseFormComponent from "@/customForm/entity/base";
import { OnlyProperties } from "@/customForm/interfaces";
import { buildListByGroupId } from "@/customForm/utils";
import dayjs from "dayjs";

const Title: React.FC<PropsWithChildren> = ({ children }) => {
  return (
    <Space align="center" style={{ marginBottom: 24 }}>
      <DecoratePoint />
      <div className={styles.title}>{children}</div>
    </Space>
  );
};

const Card: React.FC<PropsWithChildren> = ({ children }) => {
  return <div className={styles.card}>{children}</div>;
};
type ContentProps = {
  configSource: any;
  data: any;
};
const Content = (props: ContentProps) => {
  const { configSource, data } = props;

  const config = useMemo(() => {
    // debugger;
    // debugger;
    const matterContentList = configSource?.matterContentList;

    let groupList = [] as any;
    let configList = [] as any;
    if (matterContentList) {
      const temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
          };
        });
      temp.forEach((item: OnlyProperties<BaseFormComponent>) => {
        if (item.componentType === "Branch") {
          groupList.push(item);
        } else {
          if (
            item.componentType !== "ImgUpload" &&
            item.componentType !== "FileUpload"
          ) {
            configList.push(item);
          }
        }
      });
      return {
        groupList: groupList,
        configList: buildListByGroupId(configList),
      };
    } else
      return {
        groupList: [],
        configList: [],
      };
  }, [configSource]);

  const findValue = (key: string, curConfig: any) => {
    const reportContents = data?.reportContents ?? [];
    const contentValue = reportContents.find(
      (v: any) => v.contentId === key
    )?.content;

    if (contentValue) {
      if (curConfig.componentType === "TextInput") {
        return (
          (curConfig.componentOption.prefix ?? "") +
          contentValue +
          (curConfig.componentOption.suffix ?? "")
        );
      }
      if (curConfig.componentType === "DatePicker") {
        const formatStr =
          curConfig.componentOption.picker === "time"
            ? "HH:mm"
            : curConfig.componentOption.picker === "date"
            ? "YYYY-MM-DD"
            : "YYYY-MM";
        return dayjs(contentValue).format(formatStr);
      }
      return contentValue;
    }
    return undefined;
  };
  const getGroupName = (key: string) => {
    return config.groupList.find((v: any) => v.key === key)?.label ?? "";
  };
  return (
    <div>
      {config.configList.map((item) => {
        console.log(item.list);
        return (
          <div className={styles.group}>
            {item.title && item.title.length > 0 && (
              <Title>{getGroupName(item.title)}</Title>
            )}

            {item.list && item.list.length > 0 && (
              <Card>
                {item.list.map((subItem) => {
                  const value = findValue(subItem.key, subItem);

                  if (!value) {
                    return;
                  }
                  return (
                    <LabelText
                      label={subItem.label}
                      wrap
                      text={value ?? "等待填写"}
                      labelColor="rgba(139, 146, 159, 1)"
                      textColor={value ? "#000" : "gray"}
                    ></LabelText>
                  );
                })}
              </Card>
            )}
          </div>
        );
      })}
    </div>
  );
};

export default Content;
