import styles from "./review.module.css";
import ProcessTimeLine from "./timeLine";
import {
  Button,
  Flex,
  Image,
  Upload,
  UploadProps,
  Input,
  ConfigProvider,
  message,
  Form,
} from "antd";
import wodeshengqing from "@/assets/images/applyRecord/wodeshengqing.png";

import {
  CheckOutlined,
  CloseOutlined,
  FormOutlined,
  PlusOutlined,
} from "@ant-design/icons";
import { useMemo, useState } from "react";
import service from "@/service";
import { composeImgUrl } from "@/config/util";
import eventBus from "@/utils/eventBus";
import BasicModal from "@/components/BasicModal";
import {
  buildListByGroupId,
  inversionSerializationRule,
} from "@/customForm/utils";
import BaseFormComponent from "@/customForm/entity/base";
import { OnlyProperties } from "@/customForm/interfaces";
import GroupCard from "../User/SubmitApplication/components/groupCard";
import RenderComponent from "@/components/FormComponentRender/renderComponent";

const Header = () => {
  return (
    <Flex align="center" gap={12} className={styles.header}>
      <img src={wodeshengqing} alt="" style={{ width: 46, height: 46 }}></img>
      <div className={styles.modalTitle}>办理事项</div>
    </Flex>
  );
};

interface ReviewProps {
  detail: any;
  actionObj: any;
  configSource: any;
}
const Review = (props: ReviewProps) => {
  const { detail, actionObj, configSource } = props;

  const [inputStr, setInputStr] = useState("");

  const [fileList, setFileList] = useState<string[]>([]);
  const forwardAndReverseName =
    actionObj?.forwardAndReverseName?.split(",") ?? [];
  const [openDealModal, setOpenDealModal] = useState(false);
  const [form] = Form.useForm();

  const formConfig = useMemo(() => {
    let matterContentList = configSource?.matterContentList;

    if (actionObj?.examineKeys !== "all") {
      const examineKeys = actionObj?.examineKeys?.split(",") ?? [];
      matterContentList = configSource?.matterContentList?.filter((v: any) =>
        examineKeys.includes(v.fieldKey)
      );
    } else {
      matterContentList = [];
    }

    let groupList = [] as any;
    let configList = [] as any;
    if (matterContentList) {
      let temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
            validationRules: inversionSerializationRule(item.validationRules),
          };
        });

      temp.forEach((item: OnlyProperties<BaseFormComponent>) => {
        if (item.componentType === "Branch") {
          groupList.push(item);
        } else {
          configList.push(item);
        }
      });
      return {
        groupList: groupList,
        configList: buildListByGroupId(configList),
      };
    }
    return {
      groupList: [],
      configList: [],
    };
  }, [configSource, actionObj]);
  const handleChange: UploadProps["onChange"] = ({
    fileList: newFileList,
    file,
  }) => {
    if (file.status === "done") {
      const imgStr = newFileList.map((v) => v.response.data);
      setFileList(imgStr);
    }
  };

  const remakeChange = (e: any) => {
    const value = e.target.value;
    setInputStr(value);
  };

  const submitReverse = () => {
    const formData = new FormData();
    formData.append("taskId", actionObj?.taskId);
    formData.append("approveComment", inputStr);
    formData.append("attachmentList", fileList.join(","));

    formData.append("approvePass", "false");

    service.managementService.completeExamine(formData).then((res) => {
      if (res.code === 200) {
        message.success("审批完成");
        eventBus.emit("updateTableList");
      }
    });
  };
  const submitExamine = () => {
    form.validateFields().then((values) => {
      const params = [];
      for (const key in values) {
        const itemConfig = configSource?.matterContentList?.find(
          (v: any) => v.fieldKey === key
        );

        params.push({
          contentId: key,
          content: values[key],
          applicantRecordId: actionObj.id,
          downFlag:
            itemConfig.componentType === "FileUpload" ||
            itemConfig.componentType === "ImgUpload"
              ? true
              : false,
        });
      }

      service.managementService.submitForm({
        thingId: actionObj.thingId,
        reportContents: params,
      });

      const formData = new FormData();
      formData.append("taskId", actionObj?.taskId);
      formData.append("approveComment", inputStr);
      formData.append("attachmentList", fileList.join(","));
      if (actionObj.nodeName === "审批节点") {
        formData.append("approvePass", "true");
      }

      service.managementService.completeExamine(formData).then((res) => {
        if (res.code === 200) {
          message.success("审批完成");
          eventBus.emit("updateTableList");
        }
      });
    });
  };
  const getGroupName = (key: string) => {
    return formConfig.groupList.find((v: any) => v.key === key)?.label ?? "";
  };

  const deleteImg = (item: string) => {
    const imgList = fileList.filter((v) => v !== item);
    setFileList(imgList);
  };

  return (
    <div className={styles.container}>
      <BasicModal
        visible={openDealModal}
        width={600}
        zIndex={9999}
        contentStyle={{ borderRadius: 10, maxHeight: 700 }}
        onClose={function (): void {
          setOpenDealModal(false);
        }}
      >
        <Header />
        <div className={styles.modalBody}>
          <Form form={form} colon={false} layout="vertical">
            {formConfig.configList.map((item: any) => {
              return (
                <GroupCard title={getGroupName(item.title)}>
                  {item.list.map((formItem: any) => {
                    return (
                      <Form.Item
                        label={formItem.label}
                        name={formItem.key}
                        rules={[
                          {
                            required: formItem.componentOption?.require,
                            message: `请填写${formItem?.label}`,
                          },
                          ...formItem.validationRules,
                        ]}
                      >
                        <RenderComponent
                          config={formItem.componentOption}
                          componentType={formItem.componentType}
                        ></RenderComponent>
                      </Form.Item>
                    );
                  })}
                </GroupCard>
              );
            })}
            <GroupCard title={""}>
              <Form.Item label="审批意见">
                <div className={styles.editContent}>
                  <ConfigProvider
                    theme={{
                      components: {
                        Input: {
                          activeBg: "#f3f6fb",
                          activeBorderColor: "#f3f6fb",
                          activeShadow: "unset",
                        },
                      },
                    }}
                  >
                    <Input.TextArea
                      placeholder="填写审批意见"
                      onChange={remakeChange}
                      style={{
                        border: 0,
                        backgroundColor: "#f3f6fb",
                      }}
                    />
                  </ConfigProvider>
                  <Flex gap={12}>
                    {fileList.map((item) => {
                      // const extra = item.split(".");
                      return (
                        <div className={styles.imgItem}>
                          <div
                            className={styles.closeIcon}
                            onClick={() => deleteImg(item)}
                          >
                            <CloseOutlined style={{ color: "red" }} />
                          </div>
                          <Image
                            width={36}
                            height={36}
                            style={{ borderRadius: 4 }}
                            src={composeImgUrl(item)}
                          ></Image>
                        </div>
                      );
                    })}
                    <Upload
                      action="/apis/oss/upload?bucketName=cgtf"
                      accept=".pdf,image/*"
                      showUploadList={false}
                      onChange={handleChange}
                    >
                      <div className={styles.btn}>
                        <PlusOutlined />
                      </div>
                    </Upload>
                  </Flex>
                </div>
              </Form.Item>
            </GroupCard>
            <Form.Item>
              <Flex style={{ marginTop: 18 }} gap={14}>
                {actionObj.nodeName === "审批节点" && (
                  <Button
                    type="text"
                    icon={<CloseOutlined />}
                    iconPosition="start"
                    size="large"
                    onClick={submitReverse}
                    style={{
                      backgroundColor: "#EDF1F7",
                      color: "rgba(252, 74, 99, 1)",
                    }}
                  >
                    {forwardAndReverseName[1]}
                  </Button>
                )}
                <Button
                  icon={<CheckOutlined />}
                  iconPosition="start"
                  type="text"
                  size="large"
                  onClick={submitExamine}
                  style={{
                    backgroundColor: "#EDF1F7",
                    color: "rgba(46, 108, 255, 1)",
                  }}
                >
                  {forwardAndReverseName[0] ?? "通过"}
                </Button>
              </Flex>
            </Form.Item>
          </Form>
        </div>
      </BasicModal>
      <div className={styles.timeLineWrapper}>
        <ProcessTimeLine detail={detail}></ProcessTimeLine>
      </div>
      {actionObj.caseStatus?.value === "REJECT" ||
      actionObj.caseStatus?.value === "END" ? undefined : (
        <div className={styles.editWrapper}>
          <Button
            icon={<FormOutlined />}
            iconPosition="start"
            type="text"
            size="large"
            onClick={() => {
              setOpenDealModal(true);
            }}
            style={{
              backgroundColor: "#EDF1F7",
              color: "rgba(46, 108, 255, 1)",
            }}
          >
            办理
          </Button>
        </div>
      )}
    </div>
  );
};

export default Review;
